@@ -135,7 +135,7 @@ CreateMosaic(itk::ants::CommandLineParser * parser)
       maskImage->CopyInformation(rgbImage);
       maskImage->SetRegions(rgbImage->GetRequestedRegion());
       maskImage->Allocate();
-      maskImage->FillBuffer(1);
+      maskImage->FillBuffer(itk::NumericTraits<typename ImageType::PixelType>::OneValue());
 
       using ShortImageType = itk::Image<unsigned short, ImageDimension>;
       using CasterType = itk::CastImageFilter<ImageType, ShortImageType>;
@@ -826,7 +826,9 @@ CreateMosaic(itk::ants::CommandLineParser * parser)
           rgbPadder->SetInput(rgbExtracter->GetOutput());
           rgbPadder->SetPadLowerBound(lowerBound);
           rgbPadder->SetPadUpperBound(upperBound);
-          rgbPadder->SetConstant(static_cast<PixelType>(padValue));
+          RgbPixelType rgbPadValue;
+          rgbPadValue.Fill(padValue);
+          rgbPadder->SetConstant(rgbPadValue);
 
           outputRgbSlice = rgbPadder->GetOutput();
           outputRgbSlice->Update();
