@@ -15,6 +15,8 @@
 #include "itkCompositeTransform.h"
 #include "itkDisplacementFieldTransform.h"
 #include "itkIdentityTransform.h"
+#include "itkImageIOBase.h"
+#include "itkImageIOFactory.h"
 #include "itkMatrixOffsetTransformBase.h"
 #include "itkTransformFactory.h"
 #include "itkTransformFileReader.h"
@@ -208,6 +210,18 @@ antsApplyTransforms(itk::ants::CommandLineParser::Pointer & parser, unsigned int
   typename itk::ants::CommandLineParser::OptionType::Pointer inputOption = parser->GetOption("input");
   typename itk::ants::CommandLineParser::OptionType::Pointer outputOption = parser->GetOption("output");
 
+  // Time-index to extract from time-series image
+  unsigned long extractTimeIndex = 0;
+
+  bool extractTimeIndexSet = false;
+
+  typename itk::ants::CommandLineParser::OptionType::Pointer timeIndexOption = parser->GetOption("time-index");
+  if (timeIndexOption && timeIndexOption->GetNumberOfFunctions())
+  {
+    extractTimeIndexSet = true;
+    extractTimeIndex = parser->Convert<unsigned int>(timeIndexOption->GetFunction(0)->GetName());
+  }
+
   if (inputImageType == 5 && inputOption && inputOption->GetNumberOfFunctions())
   {
     if (verbose)
@@ -233,8 +247,48 @@ antsApplyTransforms(itk::ants::CommandLineParser::Pointer & parser, unsigned int
     if (verbose)
     {
       std::cout << "Input time-series image: " << inputOption->GetFunction(0)->GetName() << std::endl;
+      if (extractTimeIndexSet)
+      {
+        std::cout << "Extracting time index: " << extractTimeIndex << std::endl;
+      }
+    }
+    if (!extractTimeIndexSet)
+    {
+      ReadImage<TimeSeriesImageType>(timeSeriesImage, (inputOption->GetFunction(0)->GetName()).c_str());
+    }
+    else
+    {
+      // Modifying inputImageType, because we're going to extract a single time point
+      // if we don't do this, the code will try to read from timeSeriesImage below and output a time series
+      inputImageType = 0;
+
+      // Set up the image reader with streaming support
+      using ReaderType = itk::ImageFileReader<TimeSeriesImageType>;
+      typename ReaderType::Pointer reader = ReaderType::New();
+      reader->SetFileName((inputOption->GetFunction(0)->GetName()).c_str());
+
+      // Update the reader's output information without loading the entire image into memory
+      reader->UpdateOutputInformation();
+      typename TimeSeriesImageType::RegionType extractRegion = reader->GetOutput()->GetLargestPossibleRegion();
+      typename TimeSeriesImageType::SizeType size = extractRegion.GetSize();
+
+      // Check if the extractTimeIndex is within range
+      if (extractTimeIndex >= size[3])
+      {
+        std::cerr << "Error: time index to extract is out of range [0, " << (size[3] - 1) << "]" << std::endl;
+        return EXIT_FAILURE;
+      }
+
+      extractRegion.SetIndex(Dimension, extractTimeIndex);
+      extractRegion.SetSize(Dimension, 0);
+      using ExtracterType = itk::ExtractImageFilter<TimeSeriesImageType, ImageType>;
+      typename ExtracterType::Pointer extracter = ExtracterType::New();
+      extracter->SetInput(reader->GetOutput());
+      extracter->SetExtractionRegion(extractRegion);
+      extracter->SetDirectionCollapseToSubmatrix();
+      extracter->Update();
+      inputImages.push_back(extracter->GetOutput());
     }
-    ReadImage<TimeSeriesImageType>(timeSeriesImage, (inputOption->GetFunction(0)->GetName()).c_str());
   }
   else if (inputImageType == 2 && inputOption && inputOption->GetNumberOfFunctions())
   {
@@ -246,12 +300,60 @@ antsApplyTransforms(itk::ants::CommandLineParser::Pointer & parser, unsigned int
   }
   else if (inputImageType == 0 && inputOption && inputOption->GetNumberOfFunctions())
   {
+    const std::string inputFN = inputOption->GetFunction(0)->GetName();
+
     if (verbose)
     {
-      std::cout << "Input scalar image: " << inputOption->GetFunction(0)->GetName() << std::endl;
+      std::cout << "Input scalar image: " << inputFN << std::endl;
+    }
+
+    // As this is the default input type, check that input is correct otherwise instruct user to use
+    // the -e option
+
+    itk::ImageIOBase::Pointer imageIO =
+        itk::ImageIOFactory::CreateImageIO(inputFN.c_str(), itk::IOFileModeEnum::ReadMode);
+
+    if (!imageIO)
+    {
+      // can only check files, so skip checks if using a pointer in ANTsR / ANTsPy
+      if (verbose)
+      {
+        std::cout << "Could not create ImageIO for the input file, assuming dimension = " << Dimension <<
+            " and scalar pixel type" << std::endl;
+      }
+    }
+    else
+    {
+      imageIO->SetFileName(inputFN.c_str());
+      imageIO->ReadImageInformation();
+
+      const size_t inputDimension = imageIO->GetNumberOfDimensions();
+
+      // Check if the dimension matches
+      if (inputDimension != Dimension)
+      {
+        if (verbose)
+          {
+            std::cout << "Input image dimension does not match. Expected: " << Dimension
+                    << ", but got: " << inputDimension << std::endl << "See -e option for available input types."
+                    << std::endl;
+          }
+          return EXIT_FAILURE;
+      }
+
+      // Check if the pixel type is scalar
+      if (imageIO->GetPixelType() != itk::IOPixelEnum::SCALAR)
+      {
+        if (verbose)
+        {
+          std::cout << "Image pixel type is not scalar." << std::endl << "See -e option for available input types."
+                  << std::endl;
+        }
+        return EXIT_FAILURE;
+      }
     }
     typename ImageType::Pointer image;
-    ReadImage<ImageType>(image, (inputOption->GetFunction(0)->GetName()).c_str());
+    ReadImage<ImageType>(image, inputFN.c_str());
     inputImages.push_back(image);
   }
   else if (inputImageType == 1 && inputOption && inputOption->GetNumberOfFunctions())
@@ -620,13 +722,10 @@ antsApplyTransforms(itk::ants::CommandLineParser::Pointer & parser, unsigned int
           return EXIT_FAILURE;
         }
 
-        VectorType zeroVector(0.0);
-
         typename DisplacementFieldType::Pointer outputVectorImage = DisplacementFieldType::New();
         outputVectorImage->CopyInformation(referenceImage);
         outputVectorImage->SetRegions(referenceImage->GetRequestedRegion());
-        outputVectorImage->Allocate();
-        outputVectorImage->FillBuffer(zeroVector);
+        outputVectorImage->AllocateInitialized();
 
         itk::ImageRegionIteratorWithIndex<DisplacementFieldType> It(outputVectorImage,
                                                                     outputVectorImage->GetRequestedRegion());
@@ -663,13 +762,10 @@ antsApplyTransforms(itk::ants::CommandLineParser::Pointer & parser, unsigned int
           return EXIT_FAILURE;
         }
 
-        TensorPixelType zeroTensor(0.0);
-
         typename TensorImageType::Pointer outputTensorImage = TensorImageType::New();
         outputTensorImage->CopyInformation(referenceImage);
         outputTensorImage->SetRegions(referenceImage->GetRequestedRegion());
-        outputTensorImage->Allocate();
-        outputTensorImage->FillBuffer(zeroTensor);
+        outputTensorImage->AllocateInitialized();
 
         itk::ImageRegionIteratorWithIndex<TensorImageType> It(outputTensorImage,
                                                               outputTensorImage->GetRequestedRegion());
@@ -730,8 +826,7 @@ antsApplyTransforms(itk::ants::CommandLineParser::Pointer & parser, unsigned int
         outputTimeSeriesImage->SetDirection(direction);
         outputTimeSeriesImage->SetSpacing(spacing);
         outputTimeSeriesImage->SetRegions(region);
-        outputTimeSeriesImage->Allocate();
-        outputTimeSeriesImage->FillBuffer(0);
+        outputTimeSeriesImage->AllocateInitialized();
 
         typename ImageType::IndexType referenceIndex;
 
@@ -822,9 +917,10 @@ static void
 antsApplyTransformsInitializeCommandLineOptions(itk::ants::CommandLineParser * parser)
 {
   {
-    std::string description = std::string("This option forces the image to be treated as a specified-") +
-                              std::string("dimensional image.  If not specified, antsWarp tries to ") +
-                              std::string("infer the dimensionality from the input image.");
+    std::string description = std::string("Sets the dimensionality of transforms and scalar inputs.") +
+                              std::string("dimensional image.  This will be the same dimension as used in ") +
+                              std::string("antsRegistration. This does not change for multi-valued inputs, use ") +
+                              std::string("the -e option for time series and other multi-component images.");
 
     OptionType::Pointer option = OptionType::New();
     option->SetLongName("dimensionality");
@@ -852,6 +948,18 @@ antsApplyTransformsInitializeCommandLineOptions(itk::ants::CommandLineParser * p
     parser->AddOption(option);
   }
 
+  {
+    std::string description = std::string("Time index to extract from time series input (-e 3). ") +
+                              std::string("This selects a single slice from time series input without reading ") +
+                              std::string("the entire dataset into memory.");
+
+    OptionType::Pointer option = OptionType::New();
+    option->SetLongName("time-index");
+    option->SetUsageOption(0, "<timeIndex>");
+    option->SetDescription(description);
+    parser->AddOption(option);
+  }
+
   {
     std::string description = std::string("Currently, the only input objects supported are image ") +
                               std::string("objects.  However, the current framework allows for ") +
