@@ -31,6 +31,9 @@
 extern bool
 ANTSFileExists(const std::string & strFilename);
 
+extern bool
+ANTSFileIsImage(const std::string & filename);
+
 // Nifti stores DTI values in lower tri format but itk uses upper tri
 // currently, nifti io does nothing to deal with this. if this changes
 // the function below should be modified/eliminated.
@@ -153,6 +156,14 @@ ReadTensorImage(itk::SmartPointer<TImageType> & target, const char * file, bool
   if (!ANTSFileExists(std::string(file)))
   {
     std::cerr << " file " << std::string(file) << " does not exist . " << std::endl;
+    target = nullptr;
+    return;
+  }
+
+  if (!ANTSFileIsImage(file))
+  {
+    std::cerr << " file " << std::string(file) << " is not recognized as a supported image format . " << std::endl;
+    target = nullptr;
     return;
   }
 
@@ -210,6 +221,46 @@ ReadTensorImage(itk::SmartPointer<TImageType> & target, const char * file, bool
   }
 }
 
+// function to determine if a file name is a memory address rather than a file
+inline bool
+FileIsPointer(const char *file)
+{
+  bool fileIsPointer = false;
+
+  std::string comparetype1 = std::string("0x");
+  std::string comparetype2 = std::string(file);
+  comparetype2 = comparetype2.substr(0, 2);
+
+  if (comparetype1 == comparetype2)
+  {
+    fileIsPointer = true;
+  }
+  else
+  {
+    std::string fileString = std::string(file);
+    // Also treat file as a pointer if it is composed entirely of hex characters, and has
+    // appropriate length
+    // Windows pointers are just hex numbers without the leading 0x
+    bool fileIsHexChars = true;
+
+    std::string::iterator fileIt;
+
+    for (fileIt = fileString.begin(); fileIt < fileString.end(); ++fileIt)
+    {
+      if (!std::isxdigit(*fileIt))
+      {
+        fileIsHexChars = false;
+      }
+    }
+
+    if (fileIsHexChars && fileString.length() == (sizeof(int*) * 2))
+    {
+      fileIsPointer = true;
+    }
+  }
+  return fileIsPointer;
+}
+
 template <typename TImageType>
 // void ReadImage(typename TImageType::Pointer target, const char *file)
 bool
@@ -225,11 +276,7 @@ ReadImage(itk::SmartPointer<TImageType> & target, const char * file)
     return false;
   }
 
-  std::string comparetype1 = std::string("0x");
-  std::string comparetype2 = std::string(file);
-  comparetype2 = comparetype2.substr(0, 2);
-  // Read the image files begin
-  if (comparetype1 == comparetype2)
+  if (FileIsPointer(file))
   {
     typedef TImageType RImageType;
     void *             ptr;
@@ -250,6 +297,14 @@ ReadImage(itk::SmartPointer<TImageType> & target, const char * file)
       target = nullptr;
       return false;
     }
+
+    if (!ANTSFileIsImage(file))
+    {
+      std::cerr << " file " << std::string(file) << " is not recognized as a supported image format . " << std::endl;
+      target = nullptr;
+      return false;
+    }
+
     typedef TImageType                      ImageType;
     typedef itk::ImageFileReader<ImageType> FileSourceType;
 
@@ -355,6 +410,7 @@ ReadLabeledPointSet(itk::SmartPointer<TPointSet> & target,
 {
   if (std::string(file).length() < 3)
   {
+    std::cerr << " bad file name " << std::string(file) << std::endl;
     target = nullptr;
     return false;
   }
@@ -362,6 +418,7 @@ ReadLabeledPointSet(itk::SmartPointer<TPointSet> & target,
   if (!ANTSFileExists(std::string(file)))
   {
     std::cerr << " file " << std::string(file) << " does not exist . " << std::endl;
+    target = nullptr;
     return false;
   }
 
@@ -379,6 +436,7 @@ ReadLabeledPointSet(itk::SmartPointer<TPointSet> & target,
   {
     std::cerr << "Exception caught during point set reference file reading " << std::endl;
     std::cerr << e << std::endl;
+    target = nullptr;
     return false;
   }
 
@@ -409,6 +467,13 @@ ReadImageIntensityPointSet(itk::SmartPointer<TPointSet> & target,
     return false;
   }
 
+  if (!ANTSFileIsImage(imageFile))
+  {
+    std::cerr << " file " << std::string(imageFile) << " is not recognized as a supported image format . " << std::endl;
+    target = nullptr;
+    return false;
+  }
+
   if (std::string(maskFile).length() < 3)
   {
     std::cerr << " bad mask file name " << std::string(maskFile) << std::endl;
@@ -423,6 +488,13 @@ ReadImageIntensityPointSet(itk::SmartPointer<TPointSet> & target,
     return false;
   }
 
+  if (!ANTSFileIsImage(maskFile))
+  {
+    std::cerr << " file " << std::string(maskFile) << " is not recognized as a supported image format . " << std::endl;
+    target = nullptr;
+    return false;
+  }
+
   if (neighborhoodRadius.size() != TImage::ImageDimension)
   {
     std::cerr << " size of the neighborhood radius is not equal to the image dimension." << std::endl;
@@ -524,7 +596,7 @@ WriteImage(const itk::SmartPointer<TImageType> image, const char * file)
   // if (writer->GetImageIO->GetNumberOfComponents() == 6)
   // NiftiDTICheck<TImageType>(image,file);
 
-  if (file[0] == '0' && file[1] == 'x')
+  if (FileIsPointer(file))
   {
     void * ptr;
     sscanf(file, "%p", (void **)&ptr);
@@ -625,10 +697,8 @@ ReadWarpFromFile(std::string warpfn, std::string ext)
   //  std::cout << " spacing xv " << xvec->GetSpacing()[0]
   // << " field " << field->GetSpacing()[0] << std::endl;
 
-  unsigned int ct = 0;
   for (it.GoToBegin(); !it.IsAtEnd(); ++it)
   {
-    ct++;
     typename ImageType::IndexType index = it.GetIndex();
 
     VectorType disp;
@@ -777,7 +847,7 @@ ConvertTimeSeriesImageToMultiChannelImage(TTimeSeriesImageType * timeSeriesImage
   multiChannelImage->SetOrigin(origin);
   multiChannelImage->SetDirection(direction);
   multiChannelImage->SetVectorLength(timeSeriesSize[ImageDimension]);
-  multiChannelImage->Allocate();
+  multiChannelImage->AllocateInitialized();
 
   itk::ImageRegionIteratorWithIndex<MultiChannelImageType> It(multiChannelImage,
                                                               multiChannelImage->GetRequestedRegion());
@@ -873,7 +943,7 @@ ConvertTimeSeriesImageToFiveDimensionalImage(TTimeSeriesImageType * timeSeriesIm
 {
   enum
   {
-    ImageDimension = 3
+    ImageDimension = TTimeSeriesImageType::ImageDimension - 1
   };
 
   typename FiveDimensionalImageType::SpacingType          spacing;
@@ -908,7 +978,7 @@ ConvertTimeSeriesImageToFiveDimensionalImage(TTimeSeriesImageType * timeSeriesIm
   FiveDimensionalImage->SetSpacing(spacing);
   FiveDimensionalImage->SetOrigin(origin);
   FiveDimensionalImage->SetDirection(direction);
-  FiveDimensionalImage->Allocate();
+  FiveDimensionalImage->AllocateInitialized();
 
   itk::ImageRegionIteratorWithIndex<FiveDimensionalImageType> It(FiveDimensionalImage,
                                                                  FiveDimensionalImage->GetRequestedRegion());
@@ -934,7 +1004,7 @@ ConvertFiveDimensionalImageToTimeSeriesImage(FiveDimensionalImageType * FiveDime
 {
   enum
   {
-    ImageDimension = 3
+    ImageDimension = TimeSeriesImageType::ImageDimension - 1
   };
 
   typename FiveDimensionalImageType::SpacingType          spacing = FiveDimensionalImage->GetSpacing();
@@ -961,7 +1031,7 @@ ConvertFiveDimensionalImageToTimeSeriesImage(FiveDimensionalImageType * FiveDime
       timeSeriesDirection(d, e) = direction(d, e);
     }
   }
-  timeSeriesSize[3] = size[4];
+  timeSeriesSize[ImageDimension] = size[4];
 
   typename TimeSeriesImageType::Pointer timeSeriesImage =
     AllocImage<TimeSeriesImageType>(timeSeriesSize, timeSeriesSpacing, timeSeriesOrigin, timeSeriesDirection);
